#
# spec file for package python-transaction
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-transaction
Version:        1.4.3
Release:        5.2
Summary:        Transaction management for Python
License:        ZPL-2.1
Group:          Development/Libraries/Python
Url:            http://www.zope.org/Products/ZODB
Source:         https://pypi.python.org/packages/source/t/transaction/transaction-%{version}.tar.gz
BuildRequires:  python-setuptools
BuildRequires:  python-zope.interface
BuildRequires:  unzip
Requires:       python-zope.interface
# Documentation requirements:
BuildRequires:  python-Sphinx
BuildRequires:  python-repoze.sphinx.autointerface
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif

%description
This package contains a generic transaction implementation for Python. It is
mainly used by the ZODB, though.

Note that the data manager API, transaction.interfaces.IDataManager, is
syntactically simple, but semantically complex. The semantics were not easy to
express in the interface. This could probably use more work. The semantics are
presented in detail through examples of a sample data manager in
transaction.tests.test_SampleDataManager.

%package doc
Summary:        Transaction management for Python
Group:          Development/Libraries/Python
Requires:       %{name} = %{version}

%description doc
This package contains documentation files for %{name}.

%prep
%setup -q -n transaction-%{version}

%build
python setup.py build
python setup.py build_sphinx && rm build/sphinx/html/.buildinfo

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}

%check
python setup.py -q test

%files
%defattr(-,root,root)
%doc CHANGES.rst COPYRIGHT.txt LICENSE.txt README.rst
%{python_sitelib}/*

%files doc
%defattr(-,root,root,-)
%doc build/sphinx/html/

%changelog
* Thu May 14 2015 benoit.monin@gmx.fr
- update to version 1.4.3:
  * Added support for Python 3.4.
  * release 1.4.2 (skipped)
- switch the source archive to tar.gz
- pass -q to the test to avoid spamming the build log
* Fri Aug  2 2013 hpj@urpla.net
- Update to 1.4.1 version:
  * Document that values returned by sortKey must be strings, in order
    to guarantee total ordering.
  * Fix occasional RuntimeError: dictionary changed size during iteration
    errors in transaction.weakset on Python 3.
- Generate and install documentation in separate package
- Run tests
* Tue Jan 15 2013 p.drouand@gmail.com
- Initial python3 support
* Tue Jan 15 2013 p.drouand@gmail.com
- Update to 1.4.0 version:
  * Updated Trove classifiers.
* Tue Jan 15 2013 p.drouand@gmail.com
- Update to 1.4.0b1 version:
  * Converted existing doctests into Sphinx documentation (snippets
    are exercised via 'tox').
  * 100%% unit test coverage.
  * Backward incompatibility: raise ValueError rather than AssertionError
    for runtime errors:
  - In Transaction.doom if the transaction is in a non-doomable state.
  - In TransactionManager.attempts if passed a non-positive value.
  - In TransactionManager.free if passed a foreign transaction.
  * Declared support for Python 3.3 in setup.py, and added tox testing.
  * When a non-retryable exception was raised as the result of a call to
    transaction.manager.commit within the "attempts" machinery, the exception
    was not reraised properly. Symptom: an unrecoverable exception such as
    Unsupported: Storing blobs in <somestorage> is not supported. would be
    swallowed inappropriately.
* Wed Jun  6 2012 os-dev@jacraig.com
- Update to 1.3.0:
  * Added Sphinx API docuementation.
  * Added explicit support for PyPy.
  * Dropped use of Python3-incompatible zope.interface.implements class advisor
    in favor of zope.interface.implementer class decorator.
  * Added support for continuous integration using tox and jenkins.
  * Added setup.py docs alias (installs Sphinx and dependencies).
  * Added setup.py dev alias (runs setup.py develop plus installs nose and
    coverage).
  * Python 3.3 compatibility.
  * Fix "for attempt in transaction.attempts(x)" machinery, which would not
    retry a transaction if its implicit call to .commit() itself raised a
    transient error. Symptom: seeing conflict errors even though you thought
    you were retrying some number of times via the "attempts" machinery (the
    first attempt to generate an exception during commit would cause that
    exception to be raised).
* Tue Feb 28 2012 saschpe@suse.de
- Fix SLE_11 build by actually BuildRequiring python-devel
* Wed Feb  1 2012 saschpe@suse.de
- Update to version 1.2.0:
  * Python 3.2 compatibility.
  * Dropped Python 2.4 and 2.5 compatibility
- Set license to SPDX style (ZPL-2.1)
- Ran spec-cleaner
* Mon Oct 11 2010 coolo@novell.com
- update to 1.1.1
  * Code in ``_transaction.py`` held on to local references to traceback
  objects after calling ``sys.exc_info()`` to get one, causing
  potential reference leakages.
  * Fixed ``hexlify`` NameError in ``transaction._transaction.oid_repr``
  and add test.
* Tue Sep 14 2010 coolo@novell.com
- make it noarch for > 11.2
* Wed Jul 21 2010 cfarrell@novell.com
- Updated to 1.1.0
  New Features:
  - Transaction managers and the transaction module can be used with the
    with statement to define transaction boundaries
  - There is a new iterator function that automates dealing with
    transient errors (such as ZODB confict errors).
  Bugs fixed:
  - Fixed a bug that caused extra commit calls to be made on data
    managers under certain special circumstances.
  - When threads were reused, transaction data could leak accross them,
    causing subtle application bugs.
- Fixed zopeinterface require as per bnc#623255
- Added %%doc section
* Thu Jun 17 2010 hvogel@novell.com
- Prepare specfile for factory submission
  o pass CFLAGS
  o use the standard modname
* Wed Mar  4 2009 cfarrell1980@gmail.com
- Initial package, version 1.0a1
